@@ -36,11 +36,14 @@
 #include <Soprano/LiteralValue>
 #include <Soprano/Node>
 
+#include <Nepomuk/Vocabulary/NIE>
+
 #include <KDebug>
 #include <Soprano/Graph>
 #include "resourcewatchermanager.h"
 
 using namespace Soprano::Vocabulary;
+using namespace Nepomuk::Vocabulary;
 
 
 Nepomuk::ResourceMerger::ResourceMerger(Nepomuk::DataManagementModel* model, const QString& app,
@@ -474,7 +477,8 @@ Soprano::Node Nepomuk::ResourceMerger::resolveMappedNode(const Soprano::Node& no
     if( node.isBlank() )
         return node;
 
-    if( uri.scheme() == QLatin1String("nepomuk") ) {
+    if( uri.scheme() == QLatin1String("nepomuk") &&
+        !m_model->containsAnyStatement( uri, Soprano::Node(), Soprano::Node() ) ) {
         QString error = QString::fromLatin1("Could not resolve %1. "
                                             "You cannot create nepomuk uris using this method")
                         .arg( Soprano::Node::resourceToN3( uri ) );
@@ -534,7 +538,9 @@ void Nepomuk::ResourceMerger::removeDuplicatesInList(QList<Soprano::Statement> *
             const QUrl oldGraph = qit[0].uri();
             qit.close();
 
-            m_duplicateStatements.insert( oldGraph, st );
+            if(!m_model->isProtectedProperty(st.predicate().uri())) {
+                m_duplicateStatements.insert( oldGraph, st );
+            }
             it.remove();
         }
     }
@@ -719,9 +725,9 @@ bool Nepomuk::ResourceMerger::merge( const Soprano::Graph& stGraph )
             if( newCardinality > maxCardinality ) {
                 // Special handling for max Cardinality == 1
                 if( maxCardinality == 1 ) {
-                    // If the difference is 1, then that is okay, as the OverwriteProperties flag
-                    // has been set
-                    if( (m_flags & OverwriteProperties) && (newCardinality-maxCardinality) == 1 ) {
+                    // If the final cardinality is right, then that is okay,
+                    // as the OverwriteProperties flag has been set
+                    if( (m_flags & OverwriteProperties) && objectValues.size() == 1 ) {
                         continue;
                     }
                 }
